@@ -294,7 +294,7 @@ void tst_KDescendantProxyModel::testResetModelContent()
 {
     auto model1 = createTree("FirstModel");
     KDescendantsProxyModel proxy;
-    new QAbstractItemModelTester(&proxy);
+    QAbstractItemModelTester modelTest(&proxy);
     proxy.setSourceModel(model1.get());
     QCOMPARE(proxy.rowCount(), 6);
 
@@ -339,7 +339,7 @@ void tst_KDescendantProxyModel::testSourceModelReset()
 {
     auto model1 = createTree("FirstModel");
     KDescendantsProxyModel proxy;
-    new QAbstractItemModelTester(&proxy); // ensure no nested signals
+    QAbstractItemModelTester modelTest(&proxy); // ensure no nested signals
     QIdentityProxyModel identityProxy;
     identityProxy.setSourceModel(model1.get());
     proxy.setSourceModel(&identityProxy);
@@ -387,7 +387,7 @@ void tst_KDescendantProxyModel::testChangeSeparator()
 {
     auto model1 = createTree("FirstModel");
     KDescendantsProxyModel proxy;
-    new QAbstractItemModelTester(&proxy);
+    QAbstractItemModelTester modelTest(&proxy);
     proxy.setSourceModel(model1.get());
     proxy.setDisplayAncestorData(true);
     QSignalSpy dataChangedSpy(&proxy, &QAbstractItemModel::dataChanged);
@@ -426,7 +426,7 @@ void tst_KDescendantProxyModel::testChangeInvisibleSeparator()
 {
     auto model1 = createTree("FirstModel");
     KDescendantsProxyModel proxy;
-    new QAbstractItemModelTester(&proxy);
+    QAbstractItemModelTester modelTest(&proxy);
     proxy.setSourceModel(model1.get());
     QSignalSpy dataChangedSpy(&proxy, &QAbstractItemModel::dataChanged);
     QCOMPARE(proxy.rowCount(), 6);
@@ -464,7 +464,7 @@ void tst_KDescendantProxyModel::testRemoveSeparator()
 {
     auto model1 = createTree("FirstModel");
     KDescendantsProxyModel proxy;
-    new QAbstractItemModelTester(&proxy);
+    QAbstractItemModelTester modelTest(&proxy);
     proxy.setSourceModel(model1.get());
     QSignalSpy dataChangedSpy(&proxy, &QAbstractItemModel::dataChanged);
     proxy.setDisplayAncestorData(true);
@@ -503,7 +503,7 @@ void tst_KDescendantProxyModel::testResetCollapsedModelContent()
 {
     auto model1 = createTree("FirstModel");
     KDescendantsProxyModel proxy;
-    new QAbstractItemModelTester(&proxy);
+    QAbstractItemModelTester modelTest(&proxy);
     proxy.setExpandsByDefault(false);
     proxy.setSourceModel(model1.get());
     QCOMPARE(proxy.rowCount(), 2);
@@ -732,7 +732,7 @@ void tst_KDescendantProxyModel::testEmptyModel()
     model->insert(QModelIndex(), 0, QStringLiteral("Row0"));
     model->insert(QModelIndex(), 0, QStringLiteral("Row1"));
     KDescendantsProxyModel proxy;
-    new QAbstractItemModelTester(&proxy);
+    QAbstractItemModelTester modelTest(&proxy);
     proxy.setSourceModel(model);
     QCOMPARE(proxy.rowCount(), 0);
 }
@@ -750,7 +750,7 @@ void tst_KDescendantProxyModel::testEmptyChild()
     model->getRootNode()->knownChildren = 2;
 
     KDescendantsProxyModel proxy;
-    new QAbstractItemModelTester(&proxy);
+    QAbstractItemModelTester modelTest(&proxy);
     proxy.setSourceModel(model);
     proxy.setExpandsByDefault(false);
     QCOMPARE(proxy.rowCount(), 2);
